@@ -10,7 +10,6 @@
 #include "MenuItem.h"
 #include "MenuModel.h"
 
-#include <KCModuleInfo>
 #include <KPluginMetaData>
 
 MenuProxyModel::MenuProxyModel(QObject *parent)
@@ -69,7 +68,7 @@ bool MenuProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_
     if (!m_filterHighlightsEntries) {
         // Don't show empty categories
         QModelIndex index = sourceModel()->index(source_row, 0, source_parent);
-        MenuItem *mItem = index.data(Qt::UserRole).value<MenuItem *>();
+        auto mItem = index.data(Qt::UserRole).value<MenuItem *>();
         if (mItem->menu() && mItem->children().isEmpty()) {
             return false;
         }
@@ -81,7 +80,7 @@ bool MenuProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_
     }
 
     QModelIndex index = sourceModel()->index(source_row, 0, source_parent);
-    MenuItem *mItem = index.data(Qt::UserRole).value<MenuItem *>();
+    auto mItem = index.data(Qt::UserRole).value<MenuItem *>();
 
     if (mItem->metaData().pluginId() == QLatin1String("kcm_landingpage")) {
         return false;
@@ -112,11 +111,7 @@ Qt::ItemFlags MenuProxyModel::flags(const QModelIndex &index) const
     }
 
     QString matchText = index.data(MenuModel::UserFilterRole).toString();
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QRegExp pattern = KCategorizedSortFilterProxyModel::filterRegExp();
-#else
     QRegularExpression pattern = KCategorizedSortFilterProxyModel::filterRegularExpression();
-#endif
 
     if (!matchText.contains(pattern)) {
         return Qt::NoItemFlags;
@@ -125,30 +120,6 @@ Qt::ItemFlags MenuProxyModel::flags(const QModelIndex &index) const
     }
 }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-void MenuProxyModel::setFilterRegExp(const QString &pattern)
-{
-    if (pattern == filterRegExp()) {
-        return;
-    }
-    Q_EMIT layoutAboutToBeChanged();
-    KCategorizedSortFilterProxyModel::setFilterRegExp(pattern);
-    Q_EMIT layoutChanged();
-    Q_EMIT filterRegExpChanged();
-}
-
-QString MenuProxyModel::filterRegExp() const
-{
-    return KCategorizedSortFilterProxyModel::filterRegExp().pattern();
-}
-
-void MenuProxyModel::setFilterRegExp(const QRegExp &regExp)
-{
-    Q_EMIT layoutAboutToBeChanged();
-    KCategorizedSortFilterProxyModel::setFilterRegExp(regExp);
-    Q_EMIT layoutChanged();
-}
-#else
 void MenuProxyModel::setFilterRegularExpression(const QString &pattern)
 {
     if (pattern == filterRegularExpression()) {
@@ -171,4 +142,5 @@ void MenuProxyModel::setFilterRegularExpression(const QRegularExpression &regExp
     KCategorizedSortFilterProxyModel::setFilterRegularExpression(regExp);
     Q_EMIT layoutChanged();
 }
-#endif
+
+#include "moc_MenuProxyModel.cpp"
