@@ -12,11 +12,9 @@
 #include <QDesktopServices>
 #include <QDialogButtonBox>
 #include <QKeyEvent>
-#include <QList>
 #include <QLoggingCategory>
 #include <QMap>
 #include <QPainter>
-#include <QProcess>
 #include <QPushButton>
 #include <QScrollArea>
 #include <QStyle>
@@ -49,6 +47,7 @@ public:
     explicit CustomTitle(QWidget *parent = nullptr);
 
 protected:
+    bool event(QEvent *event) override;
     void paintEvent(QPaintEvent *event) override;
     void colorsChanged();
 };
@@ -66,7 +65,14 @@ CustomTitle::CustomTitle(QWidget *parent)
                        style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
 
     colorsChanged();
-    connect(qApp, &QApplication::paletteChanged, this, &CustomTitle::colorsChanged);
+}
+
+bool CustomTitle::event(QEvent *event)
+{
+    if (event->type() == QEvent::ApplicationPaletteChange || event->type() == QEvent::PaletteChange) {
+        this->colorsChanged();
+    }
+    return QWidget::event(event);
 }
 
 void CustomTitle::colorsChanged()
@@ -155,7 +161,7 @@ ModuleView::ModuleView(QWidget *parent)
     d->mPageWidget->layout()->setContentsMargins(0, 0, 0, 0);
 
     // Zero out only the horizontal spacing (the vertical spacing is fine)
-    auto gridLayout = static_cast<QGridLayout *>(d->mPageWidget->layout());
+    auto gridLayout = qobject_cast<QGridLayout *>(d->mPageWidget->layout());
 
     gridLayout->setHorizontalSpacing(0);
 
@@ -469,9 +475,10 @@ void ModuleView::activeModuleChanged(KPageWidgetItem *current, KPageWidgetItem *
     d->mLayout->setContentsMargins(0, 0, 0, 0);
     d->mLayout->setSpacing(0);
     d->mButtons->setContentsMargins(style()->pixelMetric(QStyle::PM_LayoutLeftMargin),
-                                    0, // Remove extra space between KCM content and bottom buttons
+                                    style()->pixelMetric(QStyle::PM_LayoutTopMargin),
                                     style()->pixelMetric(QStyle::PM_LayoutRightMargin),
                                     style()->pixelMetric(QStyle::PM_LayoutBottomMargin));
+    d->mButtons->setProperty("_breeze_force_frame", true);
     d->mPageWidget->layout()->setSpacing(0);
     if (auto titleWidget = qobject_cast<KTitleWidget *>(d->mPageWidget->pageHeader())) {
         // 18px is Standard Kirigami gridUnit for 10pt Noto Sans.
