@@ -10,15 +10,14 @@
 #include <KFileUtils>
 #include <KPluginFactory>
 #include <KPluginMetaData>
+#include <KService>
 #include <QGuiApplication>
 #include <QStandardPaths>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <KServiceTypeTrader>
-#endif
-#include <kservice.h>
 #include <set>
 
+#include "../systemsettings_app_debug.h"
+
 enum MetaDataSource {
     SystemSettings = 1,
     KInfoCenter = 2,
@@ -42,9 +41,9 @@ inline QList<KPluginMetaData> findExternalKCMModules(MetaDataSource source)
 
             QJsonObject root;
             root.insert(QLatin1String("KPlugin"), kplugin);
-            root.insert(QLatin1String("X-KDE-Weight"), service.property(QStringLiteral("X-KDE-Weight")).toInt());
-            root.insert(QLatin1String("X-KDE-KInfoCenter-Category"), service.property(QStringLiteral("X-KDE-KInfoCenter-Category")).toString());
-            root.insert(QLatin1String("X-KDE-System-Settings-Category"), service.property(QStringLiteral("X-KDE-System-Settings-Category")).toString());
+            root.insert(QLatin1String("X-KDE-Weight"), service.property<int>(QStringLiteral("X-KDE-Weight")));
+            root.insert(QLatin1String("X-KDE-KInfoCenter-Category"), service.property<QString>(QStringLiteral("X-KDE-KInfoCenter-Category")));
+            root.insert(QLatin1String("X-KDE-System-Settings-Category"), service.property<QString>(QStringLiteral("X-KDE-System-Settings-Category")));
             root.insert(QLatin1String("IsExternalApp"), true);
 
             metaDataList << KPluginMetaData(root, file);
@@ -54,13 +53,6 @@ inline QList<KPluginMetaData> findExternalKCMModules(MetaDataSource source)
 
     QList<KPluginMetaData> metaDataList;
     if (source & SystemSettings) {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        const auto servicesList = KServiceTypeTrader::self()->query(QStringLiteral("SystemSettingsExternalApp"));
-        for (const auto &s : servicesList) {
-            const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + s->entryPath());
-            metaDataList << KPluginMetaData::fromDesktopFile(path);
-        }
-#endif
         metaDataList << findExternalModulesInFilesystem(QStringLiteral("systemsettings"));
     }
 
@@ -71,7 +63,7 @@ inline QList<KPluginMetaData> findExternalKCMModules(MetaDataSource source)
     return metaDataList;
 }
 
-inline QList<KPluginMetaData> findKCMsMetaData(MetaDataSource source, bool useSystemsettingsConstraint = true)
+inline QList<KPluginMetaData> findKCMsMetaData(MetaDataSource source)
 {
     QList<KPluginMetaData> modules;
     std::set<QString> uniquePluginIds;
@@ -82,28 +74,17 @@ inline QList<KPluginMetaData> findKCMsMetaData(MetaDataSource source, bool useSy
     };
 
     // We need the exist calls because otherwise the trader language aborts if the property doesn't exist and the second part of the or is not evaluated
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    KService::List services;
-#endif
-    QVector<KPluginMetaData> metaDataList = KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms"), filter);
+    QList<KPluginMetaData> metaDataList = KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms"), filter);
     if (source & SystemSettings) {
         metaDataList << KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms/systemsettings"), filter);
         metaDataList << KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms/systemsettings_qwidgets"), filter);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        services +=
-            KServiceTypeTrader::self()->query(QStringLiteral("KCModule"),
-                                              useSystemsettingsConstraint ? QStringLiteral("[X-KDE-System-Settings-Parent-Category] != ''") : QString());
-#endif
     }
     if (source & KInfoCenter) {
         metaDataList << KPluginMetaData::findPlugins(QStringLiteral("plasma/kcms/kinfocenter"), filter);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        services += KServiceTypeTrader::self()->query(QStringLiteral("KCModule"), QStringLiteral("[X-KDE-ParentApp] == 'kinfocenter'"));
-#endif
     }
-    for (const auto &m : qAsConst(metaDataList)) {
+    for (const auto &m : std::as_const(metaDataList)) {
         // We check both since porting a module to loading view KPluginMetaData drops ".desktop" from the pluginId()
-        if (!KAuthorized::authorizeControlModule(m.pluginId()) || !KAuthorized::authorizeControlModule(m.pluginId().append(QStringLiteral(".desktop")))) {
+        if (!KAuthorized::authorizeControlModule(m.pluginId())) {
             continue;
         }
         modules << m;
@@ -112,19 +93,6 @@ inline QList<KPluginMetaData> findKCMsMetaData(MetaDataSource source, bool useSy
             qWarning() << "the plugin" << m.pluginId() << " was found in multiple namespaces";
         }
     }
-
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    for (const auto &s : qAsConst(services)) {
-        if (!s->noDisplay() && !s->exec().isEmpty() && KAuthorized::authorizeControlModule(s->menuId())) {
-            const QString path = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("kservices5/") + s->entryPath());
-            const KPluginMetaData data = KPluginMetaData::fromDesktopFile(path);
-            const bool inserted = uniquePluginIds.insert(data.pluginId()).second;
-            if (inserted) {
-                modules << data;
-            }
-        }
-    }
-#endif
     std::stable_sort(modules.begin(), modules.end(), [](const KPluginMetaData &m1, const KPluginMetaData &m2) {
         return QString::compare(m1.pluginId(), m2.pluginId(), Qt::CaseInsensitive) < 0;
     });
@@ -133,32 +101,14 @@ inline QList<KPluginMetaData> findKCMsMetaData(MetaDataSource source, bool useSy
 
 inline bool isKinfoCenterKcm(const KPluginMetaData &data)
 {
-    // KServiceTypeTrader compat
-    if (data.value(QStringLiteral("X-KDE-ParentApp")) == QLatin1String("kinfocenter")) {
-        return true;
-    }
     // external module or a KCM in the namespace
-    if (data.fileName().contains(QLatin1String("/kinfocenter/"))) {
-        return true;
-    }
-    return false;
+    return data.fileName().contains(QLatin1String("/kinfocenter/"));
 }
 
 inline KCModuleData *loadModuleData(const KPluginMetaData &data)
 {
-    if (!data.isValid()) {
-        return nullptr;
+    if (auto factory = KPluginFactory::loadFactory(data).plugin) {
+        return factory->create<KCModuleData>();
     }
-    KCModuleData *moduleData = nullptr;
-    auto loadFromMetaData = [&moduleData](const KPluginMetaData &data) {
-        if (data.isValid()) {
-            auto factory = KPluginFactory::loadFactory(data).plugin;
-            moduleData = factory ? factory->create<KCModuleData>() : nullptr;
-        }
-    };
-    loadFromMetaData(data);
-    if (!moduleData) {
-        loadFromMetaData(KPluginMetaData(QStringLiteral("kcms/") + data.fileName()));
-    }
-    return moduleData;
+    return nullptr;
 }
